@@ -34,32 +34,24 @@ class KPIMTextEdit::TextToSpeechWidgetPrivate
 {
 public:
     TextToSpeechWidgetPrivate()
-        : mNeedToHide(false)
-        , mStopButton(nullptr)
-        , mPlayPauseButton(nullptr)
-        , mConfigureButton(nullptr)
-        , mTextToSpeechInterface(nullptr)
-        , mTextToSpeechActions(nullptr)
-        , mVolume(nullptr)
     {
     }
 
-    bool mNeedToHide;
+    bool mNeedToHide = false;
     QPointer<KPIMTextEdit::TextToSpeechConfigDialog> mConfigDialog;
-    QToolButton *mStopButton;
-    QToolButton *mPlayPauseButton;
-    QToolButton *mConfigureButton;
-    AbstractTextToSpeechInterface *mTextToSpeechInterface;
-    TextToSpeechActions *mTextToSpeechActions;
-    QSlider *mVolume;
+    QToolButton *mStopButton = nullptr;
+    QToolButton *mPlayPauseButton = nullptr;
+    QToolButton *mConfigureButton = nullptr;
+    AbstractTextToSpeechInterface *mTextToSpeechInterface = nullptr;
+    TextToSpeechActions *mTextToSpeechActions = nullptr;
+    QSlider *mVolume = nullptr;
 };
 
 TextToSpeechWidget::TextToSpeechWidget(QWidget *parent)
     : QWidget(parent)
     , d(new KPIMTextEdit::TextToSpeechWidgetPrivate)
 {
-    QHBoxLayout *hbox = new QHBoxLayout;
-    setLayout(hbox);
+    QHBoxLayout *hbox = new QHBoxLayout(this);
 
     d->mTextToSpeechActions = new TextToSpeechActions(this);
     connect(d->mTextToSpeechActions, &TextToSpeechActions::stateChanged, this, &TextToSpeechWidget::stateChanged);
